==> claromentis-framework-8.13.65-b8aa1bfb.zip: web/intranet/core/classes/Session/NullSessionStorage.php <==
<?php
namespace Claromentis\Core\Session;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"] = (@$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"] ?: array()) + array();
use Symfony\Component\HttpFoundation\Session\SessionBagInterface;
use Symfony\Component\HttpFoundation\Session\Storage\MetadataBag;
use Symfony\Component\HttpFoundation\Session\Storage\SessionStorageInterface;








class NullSessionStorage implements SessionStorageInterface
{
    protected $data = [];
    protected $usage_index = 0;
    public function start()
    {
        return true;
    }
    public function isStarted()
    {
        
        
        return true;
    }
    public function getId()
    {
        
        
        return null;
    }
    public function setId($id)
    {
        
        
    }
    public function getName()
    {
        return null;
    }
    public function setName($name)
    {
        
        
    }
    public function regenerate($_c48c76b3bdb00e8b4450d26815864948 = false, $_88333bfb28068976d8001d77edd9e98e = null)
    {
        
        
    }
    public function save()
    {
        
        
    }
    public function clear()
    {
        
        
    }
    public function getBag($name)
    {
        
        
        
        return new NullAttributeBagProxy();
    }
    public function registerBag(SessionBagInterface $_aa85d70476fc85ae53687b5e6df08072)
    {
        
        
    }
    public function getMetadataBag()
    {
        return new MetadataBag();
    }
}

==> claromentis-framework-9.6.5-177028fb.zip: web/intranet/core/classes/Session/NullSessionStorage.php <==
<?php
namespace Claromentis\Core\Session;

$GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"] ?: array()) + array();
use Symfony\Component\HttpFoundation\Session\SessionBagInterface;
use Symfony\Component\HttpFoundation\Session\Storage\MetadataBag;
use Symfony\Component\HttpFoundation\Session\Storage\SessionStorageInterface;








class NullSessionStorage implements SessionStorageInterface
{
    protected $data = [];
    protected $usage_index = 0;
    public function start()
    {
        return true;
    }
    public function isStarted()
    {
        
        
        return true;
    }
    public function getId()
    {
        
        
        return null;
    }
    public function setId($id)
    {
        
        
    }
    public function getName()
    {
        return null;
    }
    public function setName($name)
    {
        
        
    }
    public function regenerate($_c48c76b3bdb00e8b4450d26815864948 = false, $_88333bfb28068976d8001d77edd9e98e = null)
    {
        
        
    }
    public function save()
    {
        
        
    }
    public function clear()
    {
        
        
    }
    public function getBag($name)
    {
        
        
        
        return new NullAttributeBagProxy();
    }
    public function registerBag(SessionBagInterface $_aa85d70476fc85ae53687b5e6df08072)
    {
        
        
    }
    public function getMetadataBag()
    {
        return new MetadataBag();
    }
}
